@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCEALARM_H
-#define INCIDENCEEDITOR_INCIDENCEALARM_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 
@@ -49,10 +48,8 @@ private:
     Ui::EventOrTodoDesktop *const mUi;
 
     KCalendarCore::Alarm::List mAlarms;
-    IncidenceDateTime *mDateTime = nullptr;
+    IncidenceDateTime *const mDateTime;
     int mEnabledAlarmCount = 0;
     bool mIsTodo = false;
 };
 }
-
-#endif
